Crate martensite_render

Crate martensite_render 

Intermediate PaintList command stream and rendering backends.

This crate provides the hardware-agnostic PaintList command stream produced by layout, plus two concrete implementations of the RenderBackend trait:

A perceptual diffing engine (diff) is provided for reftest-style verification of rendered output.

Re-exports

pub use paint::FontResource;
pub use paint::GlyphInstance;
pub use paint::GlyphRun;
pub use paint::GradientStop;
pub use paint::GradientStops;
pub use paint::PaintCommand;
pub use paint::PaintList;
pub use paint::PathBuilder;
pub use presentation::nonzero as presentation_nonzero;
pub use presentation::present_rgba_to_softbuffer;
pub use presentation::rgba_to_softbuffer;
pub use presentation::PresentationError;
pub use presentation::SoftbufferPresenter;
pub use tinyskia_backend::TinySkiaBackend;
pub use vello_backend::VelloRenderer;

Modules

diff
Perceptual image diffing engine based on DSSIM (Structural Similarity).
paint
The PaintList command stream and supporting types.
presentation
CPU pixel buffer presentation via softbuffer.
tinyskia_backend
CPU software rasterization backend built on top of tiny_skia.
vello_backend
Vello GPU rendering backend.

Structs

BezPath
A Bézier path.
Point
A 2D point.
Rect
A rectangle.

Traits

RenderBackend
Abstraction over the concrete rendering target that consumes a PaintList.